@@ -2,9 +2,8 @@ use v5.12;
 
 use warnings;
 
-package String::Tools;
+package String::Tools v0.19.045;
 # ABSTRACT: Various tools for manipulating strings.
-our $VERSION = '0.18.279'; # VERSION
 
 
 use Exporter 'import';
@@ -80,36 +79,30 @@ sub stitcher {
 sub stringify(_) {
     local ($_) = @_;
 
-    if ( not defined() ) {
-        return define();
-    } elsif ( not( my $ref = ref() ) ) {
-        return $_;
-    } elsif ( $ref eq 'ARRAY' ) {
-        return "@$_";
-        #return join( $" // ' ', map stringify, @$_ );    # What about loops?
-    } elsif ( $ref eq 'HASH' ) {
-        return "@{[%$_]}";
-        #return join( $" // ' ', map stringify, %$_ );    # What about loops?
-    } elsif ( $ref eq 'REF' && ref($$_) ne 'REF' ) {
-        return stringify($$_);
-    } elsif ( $ref eq 'SCALAR' ) {
-        return stringify($$_);
-    }
-    return "$_";
+    return not( defined() ) ? define() : do {
+        my $ref = ref();
+         !$ref                               ?            $_
+        : $ref eq 'ARRAY'                    ?          "@$_"
+        : $ref eq 'HASH'                     ?       "@{[%$_]}"
+        : $ref eq 'REF' && ref($$_) ne 'REF' ? stringify($$_)
+        : $ref eq 'SCALAR'                   ? stringify($$_)
+        :                                                "$_"
+        ;
+    };
 }
 
 
 sub subst {
     my $str  = stringify( shift );
     @_ = ( $_ ) if defined($_) && ! @_;
-
-    my %subst;
-    if ( 1 == @_ ) {
-        if ( not( my $ref = ref $_[0] ) ) { %subst = ( _ => +shift ) }
-        elsif ( $ref eq 'ARRAY' )         { %subst = @{ +shift }     }
-        elsif ( $ref eq 'HASH' )          { %subst = %{ +shift }     }
-        else                              { %subst = ( _ => +shift ) }
-    } else { %subst = @_ }
+    my %subst = 1 == @_ ? do {
+            my $ref = ref( $_[0] );
+              not($ref)       ? ( _ => +shift )
+            : $ref eq 'ARRAY' ? @{ +shift }
+            : $ref eq 'HASH'  ? %{ +shift }
+            :                   ( _ => +shift );
+        }
+        : @_;
 
     if (%subst) {
         local $_;
@@ -384,6 +377,9 @@ If C<$scalar> is a reference to an C<ARRAY>,
 returns the stringification of that array (via C<"@$scalar">).
 If C<$scalar> is a reference to a C<HASH>,
 returns the stringification of that hash (via C<"@{[%$scalar]}">).
+If C<$scalar> is a reference to a C<REF>,
+and C<$$scalar> is not reference to a C<REF>,
+calls itself as C<stringify($$scalar)>.
 If C<$scalar> is a reference to a C<SCALAR>,
 calls itself as C<stringify($$scalar)>.
 If C<$scalar> is a reference that is not one of the previously mentioned,
@@ -478,11 +474,13 @@ Nothing?
 
 =head1 SEE ALSO
 
-L<perlfunc/join>, Any templating system.
+C<stitch> is similar to L<perlfunc/join>.
+
+C<subst> is similar to any templating system.
 
 =head1 VERSION
 
-version 0.18.279
+This document describes version v0.19.045 of this module.
 
 =head1 AUTHOR
 
@@ -490,7 +488,7 @@ Bob Kleemann <bobk@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2014-2018 by Bob Kleemann.
+This software is Copyright (c) 2014-2019 by Bob Kleemann.
 
 This is free software, licensed under:
 
